Target

Struct Target 

pub struct Target<'a> {
    pub category: &'static str,
    pub instance: Option<&'a str>,
}
A standalone LogSource for logging about a named element from outside it (the runner naming <category>N), or for an ad-hoc log site.

Fields

category: &'static strinstance: Option<&'a str>

Implementations

Source

impl<'a> Target<'a>

pub fn named(category: &'static str, instance: &'a str) -> Self

A target with a category and an instance name.

pub fn category(category: &'static str) -> Self

A target with only a category (no instance name).