RtpParsedHeader

Struct RtpParsedHeader 

pub struct RtpParsedHeader {
    pub header: RtpHeader,
    pub payload_offset: usize,
}
The fields and byte length of an RTP header. Unlike RtpParsed, this does not inspect the payload or its padding count, so SRTP can parse the authenticated header before decrypting the payload and padding.

Fields

header: RtpHeader

The fixed-header fields (RtpHeader::to_bytes round-trips these).

payload_offset: usize

Byte offset immediately after the CSRC list and extension header.